/* libpbm.h - internal header file for libpbm portable bitmap library
*/

#ifndef _LIBPBM_H_
#define _LIBPBM_H_

/* Here are some routines internal to the pbm library. */

void
pbm_readpbminitrest(FILE * file,
                    int  * colsP,
                    int *  rowsP);

#endif /*_LIBPBM_H_*/
